@@ -62,7 +62,7 @@
  ** Cross Platform Headers
  *********************************************************************/
 
-#ifdef WIN32
+#if defined(_WIN32)
   #include <sys/timeb.h>
 #else
   #include <sys/time.h>
@@ -150,20 +150,10 @@ namespace ros
     bool operator>=(const T &rhs) const;
     bool operator<=(const T &rhs) const;
 
-    double toSec()  const { return (double)sec + 1e-9*(double)nsec; };
-    T& fromSec(double t) {
-      int64_t sec64 = (int64_t)floor(t);
-      if (sec64 < 0 || sec64 > std::numeric_limits<uint32_t>::max())
-        throw std::runtime_error("Time is out of dual 32-bit range");
-      sec = (uint32_t)sec64;
-      nsec = (uint32_t)boost::math::round((t-sec) * 1e9);
-      // avoid rounding errors
-      sec += (nsec / 1000000000ul);
-      nsec %= 1000000000ul;
-      return *static_cast<T*>(this);
-    }
+    double toSec()  const { return static_cast<double>(sec) + 1e-9*static_cast<double>(nsec); };
+    T& fromSec(double t);
 
-    uint64_t toNSec() const {return (uint64_t)sec*1000000000ull + (uint64_t)nsec;  }
+    uint64_t toNSec() const {return static_cast<uint64_t>(sec)*1000000000ull + static_cast<uint64_t>(nsec); }
     T& fromNSec(uint64_t t);
 
     inline bool isZero() const { return sec == 0 && nsec == 0; }
@@ -209,15 +199,15 @@ namespace ros
     static bool isSystemTime();
 
     /**
-     * \brief Returns whether or not the current time is valid.  Time is valid if it is non-zero.
+     * \brief Returns whether or not the current time source is valid.  Simulation time is valid if it is non-zero.
      */
     static bool isValid();
     /**
-     * \brief Wait for time to become valid
+     * \brief Wait for time source to become valid
      */
     static bool waitForValid();
     /**
-     * \brief Wait for time to become valid, with timeout
+     * \brief Wait for time source to become valid, with timeout
      */
     static bool waitForValid(const ros::WallDuration& timeout);
 
