@@ -32,7 +32,8 @@
 #include <gtest/gtest.h>
 #include <ros/rate.h>
 #include <ros/time.h>
-#ifndef _WIN32
+
+#if !defined(_WIN32)
 #include <sys/time.h>
 #endif
 
@@ -47,7 +48,7 @@ double epsilon = 1e-9;
 void seed_rand()
 {
   //Seed random number generator with current microseond count
-#ifndef _WIN32
+#if !defined(_WIN32)
   timeval temp_time_struct;
   gettimeofday(&temp_time_struct,NULL);
   srand(temp_time_struct.tv_usec);
@@ -537,7 +538,7 @@ void alarmHandler(int sig)
 
 TEST(Duration, sleepWithSignal)
 {
-#ifndef _WIN32
+#if !defined(_WIN32)
   signal(SIGALRM, alarmHandler);
   alarm(1);
 #endif
